@@ -11,8 +11,6 @@ from pydantic import BaseModel
 
 from .models import Flavor, NetworkInterface, Payment
 
-LATEST_API_VERSION = 3
-
 
 class TokenAdd:
     url = "/token/{token}/add"
@@ -60,8 +58,6 @@ class ServerLaunch:
         """
         Automatically renew the server with the token used, keeping it at 1 week
         expiration.
-
-        BETA FEATURE!!!
         """
 
     class Response(BaseModel):
@@ -111,6 +107,7 @@ class ServerInfo:
         expiration: int
         running: bool
         machine_id: str
+        token: str
         ipv4: str
         ipv6: str
         region: str
@@ -133,7 +130,6 @@ class ServerStop:
     method = "POST"
 
 
-# Deprecated in favor of ServerDestroy
 class ServerDelete:
     url = "/server/{machine_id}/delete"
     method = "POST"
@@ -154,6 +150,16 @@ class ServerRebuild:
     method = "POST"
 
 
+class ServerEnableAutorenew:
+    url = "/server/{machine_id}/autorenew/enable"
+    method = "POST"
+
+
+class ServerDisableAutorenew:
+    url = "/server/{machine_id}/autorenew/disable"
+    method = "POST"
+
+
 class ServersLaunchedFromToken:
     url = "/token/{token}/servers"
     method = "GET"
@@ -175,4 +181,4 @@ class OperatingSystems:
     method = "GET"
 
     class Response(BaseModel):
-        operating_systems: list[str]
+        operating_systems: List[str]
