@@ -189,6 +189,22 @@ def topup(
     return response_object
 
 
+def autorenew_enable(machine_id: str, api_endpoint: str = API_ENDPOINT) -> None:
+    """
+    Enable autorenew on a server.
+    """
+    url = api_endpoint + api.ServerEnableAutorenew.url.format(machine_id=machine_id)
+    _api_request(url, empty_post=True)
+
+
+def autorenew_disable(machine_id: str, api_endpoint: str = API_ENDPOINT) -> None:
+    """
+    Disable autorenew on a server.
+    """
+    url = api_endpoint + api.ServerDisableAutorenew.url.format(machine_id=machine_id)
+    _api_request(url, empty_post=True)
+
+
 def start(machine_id: str, api_endpoint: str = API_ENDPOINT) -> None:
     """
     Boots the server.
